.. :changelog:

History
-------
0.1.1 (2017-10-18)
---------------------

* Procura usuário por email e username ao invés de ser somente pelo username.


0.1.1 (2017-10-11)
---------------------

* First release on PyPI.
